@@ -170,7 +170,7 @@ def game_rink_map(data, good_team = None, title = None, strengths = ['all', '5v5
 
                 color_dict[event_result] = default_colors[team][event_result]
 
-    mask = np.logical_and(data.event.isin(FENWICK), data.shootout != 1)
+    mask = np.logical_and(data.event.isin(FENWICK), data.event_zone == 'OFF')
 
     some_df = data[mask].copy()
 
@@ -180,7 +180,7 @@ def game_rink_map(data, good_team = None, title = None, strengths = ['all', '5v5
 
         if strength == 'all':
 
-            df = some_df.copy()
+            df = some_df[np.logical_and(some_df.shootout != 1, some_df.penalty_shot != 1)].copy()
 
             subtitle = 'Shot attempts, all strengths | @chickenandstats\n\n'
 
